# DUCOlib: A friendly Duino-Coin Python Library.

DUCOlib strives to be the most accesible miner and mining library for [Duino-Coin](https://duinocoin.com/)
within the Python ecosystem. 


## Installation:


## Usage:


## Changelog: